@@ -4,10 +4,16 @@ import sys
 import os
 import re
 
-from os.path import join as pjoin, dirname as pdirname, \
-                    basename as pbasename, splitext
+from os.path import join as pjoin, dirname as pdirname, basename as pbasename
 
 import numscons
+from numscons.core.utils import popen_wrapper
+
+# XXX: this is ugly, better find the mathlibs with a checker 
+# XXX: this had nothing to do here, too...
+def scons_get_paths(paths):
+    import os
+    return paths.split(os.pathsep)
 
 def get_scons_path():
     """Returns the name of the directory where our local scons is."""
@@ -39,11 +45,8 @@ def built_with_mstools(env):
     return env['cc_opt'] == 'msvc'
 
 def built_with_mingw(env):
-    """Return true if built with mingw compiler."""
-    return env['cc_opt'] == 'mingw' or \
-           (sys.platform == 'win32'
-            and (env['f77_opt'] == 'g77' or
-                 env['f77_opt'] == 'gfortran'))
+    """Return true if C code built with mingw compiler."""
+    return env['CC'] == 'gcc' and sys.platform == 'win32'
 
 def built_with_gnu_f77(env):
     """Return true if f77 compiler is gnu (g77, gfortran, etc...)."""
@@ -72,23 +75,6 @@ def pyplat2sconsplat():
     else:
         return sys.platform
 
-def is_cc_suncc(fullpath):
-    """Return true if the compiler is suncc."""
-    # I wish there was a better way: we launch suncc -V, read the output, and
-    # returns true if Sun is found in the output. We cannot check the status
-    # code, because the compiler does not seem to have a way to do nothing
-    # while returning success (0).
-
-    suncc = re.compile('Sun C')
-    # Redirect stderr to stdout
-    cmd = fullpath + ' -V 2>&1'
-    out = os.popen(cmd)
-    cnt = out.read()
-    #st = out.close()
-    out.close()
-
-    return suncc.search(cnt)
-
 def get_local_toolpaths():
     """Returns the full pathname for the numscons tools directory."""
     return [pdirname(numscons.tools.__file__)]
@@ -132,6 +118,15 @@ def get_vs_version(env):
     except KeyError:
         raise RuntimeError("Could not get VS version !")
 
+def cc_version(env):
+    """Return version number as a float of the C compiler, if available, None
+    otherwise."""
+    if built_with_mstools(env):
+        ma, mi = get_vs_version(env)
+        return ma + 0.1 * mi
+
+    return None
+
 def isfortran(env, source):
     """Return 1 if any of code in source has fortran files in it, 0
     otherwise."""
@@ -166,3 +161,24 @@ def isf2py(env, source):
             if ext in fsuffixes:
                 return 1
     return 0
+
+# No easy way to retrieve this function from scons (because of the + in the
+# module name, cannot be easily imported).
+def iscplusplus(source):
+    import SCons
+
+    # We neeed to copy this too...
+    CXXSuffixes = ['.cpp', '.cc', '.cxx', '.c++', '.C++', '.mm']
+    if SCons.Util.case_sensitive_suffixes('.c', '.C'):
+        CXXSuffixes.append('.C')
+
+    if not source:
+        # Source might be None for unusual cases like SConf.
+        return 0
+    for s in source:
+        if s.sources:
+            ext = os.path.splitext(str(s.sources[0]))[1]
+            if ext in CXXSuffixes:
+                return 1
+    return 0
+
