@@ -16,7 +16,7 @@ Operating System :: MacOS
 
 NAME        = 'numscons'
 MAJOR       = 0
-MINOR       = 8
+MINOR       = 9
 MICRO       = 0
 DEV         = False
 DESCRIPTION = 'Enable to use scons within distutils to build extensions'
@@ -25,8 +25,10 @@ AUTHOR      = 'David Cournapeau'
 AUTHOR_EMAIL = 'david@ar.media.kyoto-u.ac.jp'
 PACKAGES    = ['numscons', 'numscons.core', 'numscons.checkers',
                'numscons.tools', 'numscons.numdist',
-               'numscons.checkers.tests', 'numscons.checkers.fortran']
-PACKAGE_DATA = {'numscons.core' : ['compiler.cfg', 'fcompiler.cfg', 'cxxcompiler.cfg'], 
+               'numscons.checkers.fortran']
+PACKAGE_DATA = {'numscons.core' :
+                    [os.path.join('configurations', i) for i in
+                     ['compiler.cfg', 'fcompiler.cfg', 'cxxcompiler.cfg']],
               'numscons.checkers' : ['perflib.cfg']}
 DATA_DIR    = ['numscons/scons-local']
 
@@ -45,4 +47,3 @@ def write_version():
     f.writelines("VERSION = '%s'\n" % build_verstring())
     f.writelines("DEV = %s" % DEV)
     f.close()
-    
